---
description: >-
  View details of organizations that you are in, including administration
  options if applicable.
sidebar:
  order: 9
title: roboto orgs
---
```bash
roboto orgs [-h]
            {add-role,bind-email-domain,delete,invite-user,list-email-domains,list-invites,members,register-bucket,remove-role,remove-user,show,unbind-email-domain} ...
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |

## roboto orgs add-role

Promotes a user to a more permissive org access level.

```bash
roboto orgs add-role [-h] --user USER [--role {admin,owner}]
                     [--org ORG]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--user <user>` Required | The user_id of the user to add a role for. |
| `--role {admin,owner}` | The role to grant to the specified user |
| `--org <org>` | The org_id of the org for which to add permissions for the specified user. Required only if the caller is a member of more than one org. |

## roboto orgs bind-email-domain

Binds an email domain to this org, so all new users whose emails are part of that domain will automatically be added.

```bash
roboto orgs bind-email-domain [-h] [--org ORG]
                              --email-domain EMAIL_DOMAIN
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--org <org>` | The org_id of the org for which to bind an email domain. This parameter is only required if the caller is a member of more than one org, otherwise this action will be performed implicitly on their single org. |
| `--email-domain <email_domain>` Required | The email domain to bind to an org. |

## roboto orgs delete

Deletes an existing organization

```bash
roboto orgs delete [-h] --org ORG [--ignore-prompt]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--org <org>` Required | The org_id for the org you're about to delete. |
| `--ignore-prompt` | Ignore the prompt which asks you to confirm that you'd like to delete your org. |

## roboto orgs invite-user

Invites a user to join an org.

```bash
roboto orgs invite-user [-h] --user USER [--org ORG]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--user <user>` Required | The user_id of the user to invite. |
| `--org <org>` | The org_id of the org to invite a user to. Required only if the caller is a member of more than one org. |

## roboto orgs list-email-domains

Lists the email domains associated with a particular org.

```bash
roboto orgs list-email-domains [-h] [--org ORG]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--org <org>` | The org_id of the org for which to list bound email domains. This parameter is only required if the caller is a member of more than one org, otherwise this action will be performed implicitly on their single org. |

## roboto orgs list-invites

Lists the current pending invites for a specified org

```bash
roboto orgs list-invites [-h] [--org ORG]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--org <org>` | The org_id of the org to view invites for. Required only if the caller is a member of more than one org. |

## roboto orgs members

Lists the members of an organization

```bash
roboto orgs members [-h] [--org ORG]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--org <org>` | The org_id for the org you want to see. |

## roboto orgs register-bucket

Registers an S3 bring-your-own-bucket with Roboto. Only available to premium tier orgs.

```bash
roboto orgs register-bucket [-h] [--org ORG] --bucket-name BUCKET_NAME
                            --aws-account AWS_ACCOUNT
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--org <org>` | The org_id of the org for which to register an S3 bring-your-own-bucket. This parameter is only required if the caller is a member of more than one org, otherwise this action will be performed implicitly on their single org. |
| `--bucket-name <bucket_name>` Required | The base name of the S3 bucket you want to register, e.g. 'my-company-roboto-byob' |
| `--aws-account <aws_account>` Required | The AWS account to register the bucket in. This command will only work if you also have the calling environment configured with AWS credentials for this account that the underlying boto3 client can use. For more information on configuring AWS credentials, see https://docs.aws.amazon.com/sdkref/latest/guide/standardized-credentials.html. |

## roboto orgs remove-role

Demotes a user to a less permissive org access level.

```bash
roboto orgs remove-role [-h] --user USER [--role {admin,owner}]
                        [--org ORG]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--user <user>` Required | The user_id of the user to add a role for. This can be your own user_id if you would like to step down as an admin or owner. |
| `--role {admin,owner}` | The role to remove for the specified user |
| `--org <org>` | The org_id of the org for which to remove permissions for the specified user. Required only if the caller is a member of more than one org. |

## roboto orgs remove-user

Removes a user from an organization

```bash
roboto orgs remove-user [-h] --user USER [--org ORG]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--user <user>` Required | The user_id of the user to remove. |
| `--org <org>` | The org_id of the org to remove a user from. Required only if the caller is a member of more than one org. |

## roboto orgs show

Gets metadata for a single organization

```bash
roboto orgs show [-h] [--org ORG]
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--org <org>` | The org_id for the org you want to see. |

## roboto orgs unbind-email-domain

Unbinds an email domain from this org, so all new users whose emails are part of that domain will no longer be automatically added.

```bash
roboto orgs unbind-email-domain [-h] [--org ORG]
                                --email-domain EMAIL_DOMAIN
```

**Arguments**

| Argument | Description |
| --- | --- |
| `-h, --help` | show this help message and exit |
| `--org <org>` | The org_id of the org for which to unbind an email domain. This parameter is only required if the caller is a member of more than one org, otherwise this action will be performed implicitly on their single org. |
| `--email-domain <email_domain>` Required | The email domain to unbind from an org. |
